# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class NewLocationInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_location_id': 'int',
        'location_name': 'str',
        'location_qr_id': 'int',
        'location_type': 'str',
        'location_description': 'str'
    }

    attribute_map = {
        'parent_location_id': 'parentLocationId',
        'location_name': 'locationName',
        'location_qr_id': 'locationQrId',
        'location_type': 'locationType',
        'location_description': 'locationDescription'
    }

    def __init__(self, parent_location_id=None, location_name=None, location_qr_id=None, location_type=None, location_description=None, local_vars_configuration=None):  # noqa: E501
        """NewLocationInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._parent_location_id = None
        self._location_name = None
        self._location_qr_id = None
        self._location_type = None
        self._location_description = None
        self.discriminator = None

        if parent_location_id is not None:
            self.parent_location_id = parent_location_id
        if location_name is not None:
            self.location_name = location_name
        if location_qr_id is not None:
            self.location_qr_id = location_qr_id
        if location_type is not None:
            self.location_type = location_type
        if location_description is not None:
            self.location_description = location_description

    @property
    def parent_location_id(self):
        """Gets the parent_location_id of this NewLocationInformation.  # noqa: E501


        :return: The parent_location_id of this NewLocationInformation.  # noqa: E501
        :rtype: int
        """
        return self._parent_location_id

    @parent_location_id.setter
    def parent_location_id(self, parent_location_id):
        """Sets the parent_location_id of this NewLocationInformation.


        :param parent_location_id: The parent_location_id of this NewLocationInformation.  # noqa: E501
        :type: int
        """

        self._parent_location_id = parent_location_id

    @property
    def location_name(self):
        """Gets the location_name of this NewLocationInformation.  # noqa: E501


        :return: The location_name of this NewLocationInformation.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this NewLocationInformation.


        :param location_name: The location_name of this NewLocationInformation.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def location_qr_id(self):
        """Gets the location_qr_id of this NewLocationInformation.  # noqa: E501


        :return: The location_qr_id of this NewLocationInformation.  # noqa: E501
        :rtype: int
        """
        return self._location_qr_id

    @location_qr_id.setter
    def location_qr_id(self, location_qr_id):
        """Sets the location_qr_id of this NewLocationInformation.


        :param location_qr_id: The location_qr_id of this NewLocationInformation.  # noqa: E501
        :type: int
        """

        self._location_qr_id = location_qr_id

    @property
    def location_type(self):
        """Gets the location_type of this NewLocationInformation.  # noqa: E501


        :return: The location_type of this NewLocationInformation.  # noqa: E501
        :rtype: str
        """
        return self._location_type

    @location_type.setter
    def location_type(self, location_type):
        """Sets the location_type of this NewLocationInformation.


        :param location_type: The location_type of this NewLocationInformation.  # noqa: E501
        :type: str
        """

        self._location_type = location_type

    @property
    def location_description(self):
        """Gets the location_description of this NewLocationInformation.  # noqa: E501


        :return: The location_description of this NewLocationInformation.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this NewLocationInformation.


        :param location_description: The location_description of this NewLocationInformation.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewLocationInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewLocationInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from cdbApi.api.authentication_api import AuthenticationApi
from cdbApi.api.downloads_api import DownloadsApi
from cdbApi.api.item_api import ItemApi
from cdbApi.api.log_api import LogApi
from cdbApi.api.property_type_api import PropertyTypeApi
from cdbApi.api.property_value_api import PropertyValueApi
from cdbApi.api.test_api import TestApi
from cdbApi.api.users_api import UsersApi
from cdbApi.api.cable_catalog_items_api import CableCatalogItemsApi
from cdbApi.api.domain_api import DomainApi
from cdbApi.api.location_items_api import LocationItemsApi
from cdbApi.api.machine_design_items_api import MachineDesignItemsApi
from cdbApi.api.sources_api import SourcesApi

# import ApiClient
from cdbApi.api_client import ApiClient
from cdbApi.configuration import Configuration
from cdbApi.exceptions import OpenApiException
from cdbApi.exceptions import ApiTypeError
from cdbApi.exceptions import ApiValueError
from cdbApi.exceptions import ApiKeyError
from cdbApi.exceptions import ApiException
# import models into sdk package
from cdbApi.models.allowed_property_value import AllowedPropertyValue
from cdbApi.models.api_exception_message import ApiExceptionMessage
from cdbApi.models.api_exception_message_exception import ApiExceptionMessageException
from cdbApi.models.api_exception_message_exception_cause import ApiExceptionMessageExceptionCause
from cdbApi.models.api_exception_message_exception_cause_stack_trace import ApiExceptionMessageExceptionCauseStackTrace
from cdbApi.models.api_exception_message_exception_cause_suppressed import ApiExceptionMessageExceptionCauseSuppressed
from cdbApi.models.connector import Connector
from cdbApi.models.connector_type import ConnectorType
from cdbApi.models.date_param import DateParam
from cdbApi.models.domain import Domain
from cdbApi.models.entity_info import EntityInfo
from cdbApi.models.entity_type import EntityType
from cdbApi.models.file_upload_object import FileUploadObject
from cdbApi.models.inline_object import InlineObject
from cdbApi.models.item import Item
from cdbApi.models.item_category import ItemCategory
from cdbApi.models.item_connector import ItemConnector
from cdbApi.models.item_domain_cable import ItemDomainCable
from cdbApi.models.item_domain_cable_catalog import ItemDomainCableCatalog
from cdbApi.models.item_domain_catalog import ItemDomainCatalog
from cdbApi.models.item_domain_catalog_all_of import ItemDomainCatalogAllOf
from cdbApi.models.item_domain_catalog_search_result import ItemDomainCatalogSearchResult
from cdbApi.models.item_domain_inventory import ItemDomainInventory
from cdbApi.models.item_domain_inventory_all_of import ItemDomainInventoryAllOf
from cdbApi.models.item_domain_location import ItemDomainLocation
from cdbApi.models.item_domain_location_all_of import ItemDomainLocationAllOf
from cdbApi.models.item_domain_maarc import ItemDomainMAARC
from cdbApi.models.item_domain_machine_design import ItemDomainMachineDesign
from cdbApi.models.item_domain_machine_design_all_of import ItemDomainMachineDesignAllOf
from cdbApi.models.item_domain_md_search_result import ItemDomainMdSearchResult
from cdbApi.models.item_element import ItemElement
from cdbApi.models.item_element_history import ItemElementHistory
from cdbApi.models.item_element_relationship import ItemElementRelationship
from cdbApi.models.item_element_relationship_history import ItemElementRelationshipHistory
from cdbApi.models.item_hierarchy import ItemHierarchy
from cdbApi.models.item_location_information import ItemLocationInformation
from cdbApi.models.item_membership import ItemMembership
from cdbApi.models.item_permissions import ItemPermissions
from cdbApi.models.item_project import ItemProject
from cdbApi.models.item_resource import ItemResource
from cdbApi.models.item_source import ItemSource
from cdbApi.models.item_status_basic_object import ItemStatusBasicObject
from cdbApi.models.item_type import ItemType
from cdbApi.models.list_tbl import ListTbl
from cdbApi.models.locatable_item import LocatableItem
from cdbApi.models.location_history_object import LocationHistoryObject
from cdbApi.models.log import Log
from cdbApi.models.log_entry_edit_information import LogEntryEditInformation
from cdbApi.models.new_location_information import NewLocationInformation
from cdbApi.models.property_metadata import PropertyMetadata
from cdbApi.models.property_type import PropertyType
from cdbApi.models.property_value import PropertyValue
from cdbApi.models.property_value_history import PropertyValueHistory
from cdbApi.models.relationship_type import RelationshipType
from cdbApi.models.relationship_type_handler import RelationshipTypeHandler
from cdbApi.models.resource_type import ResourceType
from cdbApi.models.resource_type_category import ResourceTypeCategory
from cdbApi.models.role_type import RoleType
from cdbApi.models.simple_location_information import SimpleLocationInformation
from cdbApi.models.source import Source
from cdbApi.models.user_group import UserGroup
from cdbApi.models.user_info import UserInfo
from cdbApi.models.user_role import UserRole




# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class Connector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'property_value_list': 'list[PropertyValue]',
        'item_connector_list': 'list[ItemConnector]',
        'connector_type': 'ConnectorType',
        'resource_type': 'ResourceType',
        'is_male': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'property_value_list': 'propertyValueList',
        'item_connector_list': 'itemConnectorList',
        'connector_type': 'connectorType',
        'resource_type': 'resourceType',
        'is_male': 'isMale'
    }

    def __init__(self, id=None, name=None, description=None, property_value_list=None, item_connector_list=None, connector_type=None, resource_type=None, is_male=None, local_vars_configuration=None):  # noqa: E501
        """Connector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._property_value_list = None
        self._item_connector_list = None
        self._connector_type = None
        self._resource_type = None
        self._is_male = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if property_value_list is not None:
            self.property_value_list = property_value_list
        if item_connector_list is not None:
            self.item_connector_list = item_connector_list
        if connector_type is not None:
            self.connector_type = connector_type
        if resource_type is not None:
            self.resource_type = resource_type
        self.is_male = is_male

    @property
    def id(self):
        """Gets the id of this Connector.  # noqa: E501


        :return: The id of this Connector.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Connector.


        :param id: The id of this Connector.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Connector.  # noqa: E501


        :return: The name of this Connector.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Connector.


        :param name: The name of this Connector.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 64):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Connector.  # noqa: E501


        :return: The description of this Connector.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Connector.


        :param description: The description of this Connector.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def property_value_list(self):
        """Gets the property_value_list of this Connector.  # noqa: E501


        :return: The property_value_list of this Connector.  # noqa: E501
        :rtype: list[PropertyValue]
        """
        return self._property_value_list

    @property_value_list.setter
    def property_value_list(self, property_value_list):
        """Sets the property_value_list of this Connector.


        :param property_value_list: The property_value_list of this Connector.  # noqa: E501
        :type: list[PropertyValue]
        """

        self._property_value_list = property_value_list

    @property
    def item_connector_list(self):
        """Gets the item_connector_list of this Connector.  # noqa: E501


        :return: The item_connector_list of this Connector.  # noqa: E501
        :rtype: list[ItemConnector]
        """
        return self._item_connector_list

    @item_connector_list.setter
    def item_connector_list(self, item_connector_list):
        """Sets the item_connector_list of this Connector.


        :param item_connector_list: The item_connector_list of this Connector.  # noqa: E501
        :type: list[ItemConnector]
        """

        self._item_connector_list = item_connector_list

    @property
    def connector_type(self):
        """Gets the connector_type of this Connector.  # noqa: E501


        :return: The connector_type of this Connector.  # noqa: E501
        :rtype: ConnectorType
        """
        return self._connector_type

    @connector_type.setter
    def connector_type(self, connector_type):
        """Sets the connector_type of this Connector.


        :param connector_type: The connector_type of this Connector.  # noqa: E501
        :type: ConnectorType
        """

        self._connector_type = connector_type

    @property
    def resource_type(self):
        """Gets the resource_type of this Connector.  # noqa: E501


        :return: The resource_type of this Connector.  # noqa: E501
        :rtype: ResourceType
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this Connector.


        :param resource_type: The resource_type of this Connector.  # noqa: E501
        :type: ResourceType
        """

        self._resource_type = resource_type

    @property
    def is_male(self):
        """Gets the is_male of this Connector.  # noqa: E501


        :return: The is_male of this Connector.  # noqa: E501
        :rtype: bool
        """
        return self._is_male

    @is_male.setter
    def is_male(self, is_male):
        """Sets the is_male of this Connector.


        :param is_male: The is_male of this Connector.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_male is None:  # noqa: E501
            raise ValueError("Invalid value for `is_male`, must not be `None`")  # noqa: E501

        self._is_male = is_male

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Connector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Connector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class LocationHistoryObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location_details': 'str',
        'location_item': 'Item',
        'location_single_node_hierarchy': 'ItemHierarchy',
        'entered_on_date_time': 'datetime',
        'entered_by_user': 'UserInfo'
    }

    attribute_map = {
        'location_details': 'locationDetails',
        'location_item': 'locationItem',
        'location_single_node_hierarchy': 'locationSingleNodeHierarchy',
        'entered_on_date_time': 'enteredOnDateTime',
        'entered_by_user': 'enteredByUser'
    }

    def __init__(self, location_details=None, location_item=None, location_single_node_hierarchy=None, entered_on_date_time=None, entered_by_user=None, local_vars_configuration=None):  # noqa: E501
        """LocationHistoryObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._location_details = None
        self._location_item = None
        self._location_single_node_hierarchy = None
        self._entered_on_date_time = None
        self._entered_by_user = None
        self.discriminator = None

        if location_details is not None:
            self.location_details = location_details
        if location_item is not None:
            self.location_item = location_item
        if location_single_node_hierarchy is not None:
            self.location_single_node_hierarchy = location_single_node_hierarchy
        if entered_on_date_time is not None:
            self.entered_on_date_time = entered_on_date_time
        if entered_by_user is not None:
            self.entered_by_user = entered_by_user

    @property
    def location_details(self):
        """Gets the location_details of this LocationHistoryObject.  # noqa: E501


        :return: The location_details of this LocationHistoryObject.  # noqa: E501
        :rtype: str
        """
        return self._location_details

    @location_details.setter
    def location_details(self, location_details):
        """Sets the location_details of this LocationHistoryObject.


        :param location_details: The location_details of this LocationHistoryObject.  # noqa: E501
        :type: str
        """

        self._location_details = location_details

    @property
    def location_item(self):
        """Gets the location_item of this LocationHistoryObject.  # noqa: E501


        :return: The location_item of this LocationHistoryObject.  # noqa: E501
        :rtype: Item
        """
        return self._location_item

    @location_item.setter
    def location_item(self, location_item):
        """Sets the location_item of this LocationHistoryObject.


        :param location_item: The location_item of this LocationHistoryObject.  # noqa: E501
        :type: Item
        """

        self._location_item = location_item

    @property
    def location_single_node_hierarchy(self):
        """Gets the location_single_node_hierarchy of this LocationHistoryObject.  # noqa: E501


        :return: The location_single_node_hierarchy of this LocationHistoryObject.  # noqa: E501
        :rtype: ItemHierarchy
        """
        return self._location_single_node_hierarchy

    @location_single_node_hierarchy.setter
    def location_single_node_hierarchy(self, location_single_node_hierarchy):
        """Sets the location_single_node_hierarchy of this LocationHistoryObject.


        :param location_single_node_hierarchy: The location_single_node_hierarchy of this LocationHistoryObject.  # noqa: E501
        :type: ItemHierarchy
        """

        self._location_single_node_hierarchy = location_single_node_hierarchy

    @property
    def entered_on_date_time(self):
        """Gets the entered_on_date_time of this LocationHistoryObject.  # noqa: E501


        :return: The entered_on_date_time of this LocationHistoryObject.  # noqa: E501
        :rtype: datetime
        """
        return self._entered_on_date_time

    @entered_on_date_time.setter
    def entered_on_date_time(self, entered_on_date_time):
        """Sets the entered_on_date_time of this LocationHistoryObject.


        :param entered_on_date_time: The entered_on_date_time of this LocationHistoryObject.  # noqa: E501
        :type: datetime
        """

        self._entered_on_date_time = entered_on_date_time

    @property
    def entered_by_user(self):
        """Gets the entered_by_user of this LocationHistoryObject.  # noqa: E501


        :return: The entered_by_user of this LocationHistoryObject.  # noqa: E501
        :rtype: UserInfo
        """
        return self._entered_by_user

    @entered_by_user.setter
    def entered_by_user(self, entered_by_user):
        """Sets the entered_by_user of this LocationHistoryObject.


        :param entered_by_user: The entered_by_user of this LocationHistoryObject.  # noqa: E501
        :type: UserInfo
        """

        self._entered_by_user = entered_by_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationHistoryObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LocationHistoryObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class EntityInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'is_group_writeable': 'bool',
        'created_on_date_time': 'datetime',
        'last_modified_on_date_time': 'datetime',
        'obsoleted_on_date_time': 'datetime',
        'owner_user_group_name': 'str',
        'owner_username': 'str',
        'created_by_username': 'str',
        'obsoleted_by_username': 'str',
        'last_modified_by_username': 'str'
    }

    attribute_map = {
        'id': 'id',
        'is_group_writeable': 'isGroupWriteable',
        'created_on_date_time': 'createdOnDateTime',
        'last_modified_on_date_time': 'lastModifiedOnDateTime',
        'obsoleted_on_date_time': 'obsoletedOnDateTime',
        'owner_user_group_name': 'ownerUserGroupName',
        'owner_username': 'ownerUsername',
        'created_by_username': 'createdByUsername',
        'obsoleted_by_username': 'obsoletedByUsername',
        'last_modified_by_username': 'lastModifiedByUsername'
    }

    def __init__(self, id=None, is_group_writeable=None, created_on_date_time=None, last_modified_on_date_time=None, obsoleted_on_date_time=None, owner_user_group_name=None, owner_username=None, created_by_username=None, obsoleted_by_username=None, last_modified_by_username=None, local_vars_configuration=None):  # noqa: E501
        """EntityInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._is_group_writeable = None
        self._created_on_date_time = None
        self._last_modified_on_date_time = None
        self._obsoleted_on_date_time = None
        self._owner_user_group_name = None
        self._owner_username = None
        self._created_by_username = None
        self._obsoleted_by_username = None
        self._last_modified_by_username = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if is_group_writeable is not None:
            self.is_group_writeable = is_group_writeable
        self.created_on_date_time = created_on_date_time
        self.last_modified_on_date_time = last_modified_on_date_time
        if obsoleted_on_date_time is not None:
            self.obsoleted_on_date_time = obsoleted_on_date_time
        if owner_user_group_name is not None:
            self.owner_user_group_name = owner_user_group_name
        if owner_username is not None:
            self.owner_username = owner_username
        if created_by_username is not None:
            self.created_by_username = created_by_username
        if obsoleted_by_username is not None:
            self.obsoleted_by_username = obsoleted_by_username
        if last_modified_by_username is not None:
            self.last_modified_by_username = last_modified_by_username

    @property
    def id(self):
        """Gets the id of this EntityInfo.  # noqa: E501


        :return: The id of this EntityInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EntityInfo.


        :param id: The id of this EntityInfo.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def is_group_writeable(self):
        """Gets the is_group_writeable of this EntityInfo.  # noqa: E501


        :return: The is_group_writeable of this EntityInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_group_writeable

    @is_group_writeable.setter
    def is_group_writeable(self, is_group_writeable):
        """Sets the is_group_writeable of this EntityInfo.


        :param is_group_writeable: The is_group_writeable of this EntityInfo.  # noqa: E501
        :type: bool
        """

        self._is_group_writeable = is_group_writeable

    @property
    def created_on_date_time(self):
        """Gets the created_on_date_time of this EntityInfo.  # noqa: E501


        :return: The created_on_date_time of this EntityInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on_date_time

    @created_on_date_time.setter
    def created_on_date_time(self, created_on_date_time):
        """Sets the created_on_date_time of this EntityInfo.


        :param created_on_date_time: The created_on_date_time of this EntityInfo.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_on_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `created_on_date_time`, must not be `None`")  # noqa: E501

        self._created_on_date_time = created_on_date_time

    @property
    def last_modified_on_date_time(self):
        """Gets the last_modified_on_date_time of this EntityInfo.  # noqa: E501


        :return: The last_modified_on_date_time of this EntityInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_on_date_time

    @last_modified_on_date_time.setter
    def last_modified_on_date_time(self, last_modified_on_date_time):
        """Sets the last_modified_on_date_time of this EntityInfo.


        :param last_modified_on_date_time: The last_modified_on_date_time of this EntityInfo.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and last_modified_on_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `last_modified_on_date_time`, must not be `None`")  # noqa: E501

        self._last_modified_on_date_time = last_modified_on_date_time

    @property
    def obsoleted_on_date_time(self):
        """Gets the obsoleted_on_date_time of this EntityInfo.  # noqa: E501


        :return: The obsoleted_on_date_time of this EntityInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._obsoleted_on_date_time

    @obsoleted_on_date_time.setter
    def obsoleted_on_date_time(self, obsoleted_on_date_time):
        """Sets the obsoleted_on_date_time of this EntityInfo.


        :param obsoleted_on_date_time: The obsoleted_on_date_time of this EntityInfo.  # noqa: E501
        :type: datetime
        """

        self._obsoleted_on_date_time = obsoleted_on_date_time

    @property
    def owner_user_group_name(self):
        """Gets the owner_user_group_name of this EntityInfo.  # noqa: E501


        :return: The owner_user_group_name of this EntityInfo.  # noqa: E501
        :rtype: str
        """
        return self._owner_user_group_name

    @owner_user_group_name.setter
    def owner_user_group_name(self, owner_user_group_name):
        """Sets the owner_user_group_name of this EntityInfo.


        :param owner_user_group_name: The owner_user_group_name of this EntityInfo.  # noqa: E501
        :type: str
        """

        self._owner_user_group_name = owner_user_group_name

    @property
    def owner_username(self):
        """Gets the owner_username of this EntityInfo.  # noqa: E501


        :return: The owner_username of this EntityInfo.  # noqa: E501
        :rtype: str
        """
        return self._owner_username

    @owner_username.setter
    def owner_username(self, owner_username):
        """Sets the owner_username of this EntityInfo.


        :param owner_username: The owner_username of this EntityInfo.  # noqa: E501
        :type: str
        """

        self._owner_username = owner_username

    @property
    def created_by_username(self):
        """Gets the created_by_username of this EntityInfo.  # noqa: E501


        :return: The created_by_username of this EntityInfo.  # noqa: E501
        :rtype: str
        """
        return self._created_by_username

    @created_by_username.setter
    def created_by_username(self, created_by_username):
        """Sets the created_by_username of this EntityInfo.


        :param created_by_username: The created_by_username of this EntityInfo.  # noqa: E501
        :type: str
        """

        self._created_by_username = created_by_username

    @property
    def obsoleted_by_username(self):
        """Gets the obsoleted_by_username of this EntityInfo.  # noqa: E501


        :return: The obsoleted_by_username of this EntityInfo.  # noqa: E501
        :rtype: str
        """
        return self._obsoleted_by_username

    @obsoleted_by_username.setter
    def obsoleted_by_username(self, obsoleted_by_username):
        """Sets the obsoleted_by_username of this EntityInfo.


        :param obsoleted_by_username: The obsoleted_by_username of this EntityInfo.  # noqa: E501
        :type: str
        """

        self._obsoleted_by_username = obsoleted_by_username

    @property
    def last_modified_by_username(self):
        """Gets the last_modified_by_username of this EntityInfo.  # noqa: E501


        :return: The last_modified_by_username of this EntityInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by_username

    @last_modified_by_username.setter
    def last_modified_by_username(self, last_modified_by_username):
        """Sets the last_modified_by_username of this EntityInfo.


        :param last_modified_by_username: The last_modified_by_username of this EntityInfo.  # noqa: E501
        :type: str
        """

        self._last_modified_by_username = last_modified_by_username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EntityInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemHierarchy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item': 'Item',
        'derived_item': 'Item',
        'child_items': 'list[ItemHierarchy]',
        'element_id': 'int',
        'element_name': 'str',
        'sort_order': 'float',
        'derived_element_name': 'str',
        'parent_item': 'Item'
    }

    attribute_map = {
        'item': 'item',
        'derived_item': 'derivedItem',
        'child_items': 'childItems',
        'element_id': 'elementId',
        'element_name': 'elementName',
        'sort_order': 'sortOrder',
        'derived_element_name': 'derivedElementName',
        'parent_item': 'parentItem'
    }

    def __init__(self, item=None, derived_item=None, child_items=None, element_id=None, element_name=None, sort_order=None, derived_element_name=None, parent_item=None, local_vars_configuration=None):  # noqa: E501
        """ItemHierarchy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item = None
        self._derived_item = None
        self._child_items = None
        self._element_id = None
        self._element_name = None
        self._sort_order = None
        self._derived_element_name = None
        self._parent_item = None
        self.discriminator = None

        if item is not None:
            self.item = item
        if derived_item is not None:
            self.derived_item = derived_item
        if child_items is not None:
            self.child_items = child_items
        if element_id is not None:
            self.element_id = element_id
        if element_name is not None:
            self.element_name = element_name
        if sort_order is not None:
            self.sort_order = sort_order
        if derived_element_name is not None:
            self.derived_element_name = derived_element_name
        if parent_item is not None:
            self.parent_item = parent_item

    @property
    def item(self):
        """Gets the item of this ItemHierarchy.  # noqa: E501


        :return: The item of this ItemHierarchy.  # noqa: E501
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this ItemHierarchy.


        :param item: The item of this ItemHierarchy.  # noqa: E501
        :type: Item
        """

        self._item = item

    @property
    def derived_item(self):
        """Gets the derived_item of this ItemHierarchy.  # noqa: E501


        :return: The derived_item of this ItemHierarchy.  # noqa: E501
        :rtype: Item
        """
        return self._derived_item

    @derived_item.setter
    def derived_item(self, derived_item):
        """Sets the derived_item of this ItemHierarchy.


        :param derived_item: The derived_item of this ItemHierarchy.  # noqa: E501
        :type: Item
        """

        self._derived_item = derived_item

    @property
    def child_items(self):
        """Gets the child_items of this ItemHierarchy.  # noqa: E501


        :return: The child_items of this ItemHierarchy.  # noqa: E501
        :rtype: list[ItemHierarchy]
        """
        return self._child_items

    @child_items.setter
    def child_items(self, child_items):
        """Sets the child_items of this ItemHierarchy.


        :param child_items: The child_items of this ItemHierarchy.  # noqa: E501
        :type: list[ItemHierarchy]
        """

        self._child_items = child_items

    @property
    def element_id(self):
        """Gets the element_id of this ItemHierarchy.  # noqa: E501


        :return: The element_id of this ItemHierarchy.  # noqa: E501
        :rtype: int
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this ItemHierarchy.


        :param element_id: The element_id of this ItemHierarchy.  # noqa: E501
        :type: int
        """

        self._element_id = element_id

    @property
    def element_name(self):
        """Gets the element_name of this ItemHierarchy.  # noqa: E501


        :return: The element_name of this ItemHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._element_name

    @element_name.setter
    def element_name(self, element_name):
        """Sets the element_name of this ItemHierarchy.


        :param element_name: The element_name of this ItemHierarchy.  # noqa: E501
        :type: str
        """

        self._element_name = element_name

    @property
    def sort_order(self):
        """Gets the sort_order of this ItemHierarchy.  # noqa: E501


        :return: The sort_order of this ItemHierarchy.  # noqa: E501
        :rtype: float
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this ItemHierarchy.


        :param sort_order: The sort_order of this ItemHierarchy.  # noqa: E501
        :type: float
        """

        self._sort_order = sort_order

    @property
    def derived_element_name(self):
        """Gets the derived_element_name of this ItemHierarchy.  # noqa: E501


        :return: The derived_element_name of this ItemHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._derived_element_name

    @derived_element_name.setter
    def derived_element_name(self, derived_element_name):
        """Sets the derived_element_name of this ItemHierarchy.


        :param derived_element_name: The derived_element_name of this ItemHierarchy.  # noqa: E501
        :type: str
        """

        self._derived_element_name = derived_element_name

    @property
    def parent_item(self):
        """Gets the parent_item of this ItemHierarchy.  # noqa: E501


        :return: The parent_item of this ItemHierarchy.  # noqa: E501
        :rtype: Item
        """
        return self._parent_item

    @parent_item.setter
    def parent_item(self, parent_item):
        """Sets the parent_item of this ItemHierarchy.


        :param parent_item: The parent_item of this ItemHierarchy.  # noqa: E501
        :type: Item
        """

        self._parent_item = parent_item

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemHierarchy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemHierarchy):
            return True

        return self.to_dict() != other.to_dict()
